/********************************************************************
 * Job Ticket API (JTAPI) fsgjt_insert_sheet.h
 *  
 * Copyright (c) 2004 High North Inc.
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_INSERT_SHEET_H
#define FSGJT_INSERT_SHEET_H

#include <fsgjt.h>
#include <fsgjt_enums.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_INSERT_SHEET_OBJECT  "JINS"

/************************************************************
 * InsertSheet attributes
 ***********************************************************/
/* Single value where type is fsgjt_insert_sheet_content_t */
/* (InsertSheetContentEnum) */
#define FSGJT_INSERT_SHEET_CONTENT           "insert-sheet-content"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_INSERT_SHEET_COUNT             "insert-sheet-count"

/* Single value where type is fsgjt_object_t (Media) */
#define FSGJT_INSERT_SHEET_MEDIA             "insert-sheet-media"

/* Multiple values where type is fsgjt_object_t (PageRange) */
#define FSGJT_INSERT_SHEET_PAGES             "insert-sheet-pages"

/* Single value where type is fsgjt_position_t (PositionEnum) */
#define FSGJT_INSERT_SHEET_POSITION          "insert-sheet-position"

/************************************************************
 * fsgjtNewInsertSheet - Creates a InsertSheet object having
 * the provided position and page ranges.
 *
 * param (output) fsgjt_object_t* insertSheet - Pointer to
 *      the new InsertSheet object to create
 * param (input) fsgjt_position_t position - Position of
 *      insert sheet (e.g., before)
 * param (input) fsgjt_object_t* pages - list of PageRange
 *      objects (scope) for the insert sheet operation
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewInsertSheet(
               fsgjt_object_t* insertSheet,
               fsgjt_position_t position,
               fsgjt_object_t* pages);

#endif /* FSGJT_INSERT_SHEET_H */
