/********************************************************************
 * Job Ticket API (JTAPI) fsgjt_media.h
 *  
 * Copyright (c) 2004 High North Inc.
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_MEDIA_H
#define FSGJT_MEDIA_H

#include <fsgjt.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_MEDIA_OBJECT         "JMED"

/************************************************************
 * Media attributes
 ***********************************************************/
/* Single value where type is fsgjt_media_coating_t */
/* (MediaCoatingEnum) */
#define FSGJT_MEDIA_BACK_COATING             "media-back-coating"

/* Single value where type is fsgjt_media_color_t (MediaColorEnum) */
#define FSGJT_MEDIA_COLOR                    "media-color"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_MEDIA_COLOR_NAME               "media-color-name"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_MEDIA_DESCRIPTION              "media-description"

/* Single value where type is fsgjt_media_coating_t */
/* (MediaCoatingEnum) */
#define FSGJT_MEDIA_FRONT_COATING            "media-front-coating"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_MEDIA_HOLE_COUNT               "media-hole-count"

/* Single value where type is fsgjt_input_tray_name_t */
/* (InputTrayNameEnum) */
#define FSGJT_MEDIA_INPUT_TRAY_NAME          "media-input-tray-name"

/* Single value where type is fsgjt_present_t (PresentEnum) */
#define FSGJT_MEDIA_MANUAL_FEED              "media-manual-feed"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_MEDIA_NAME                     "media-name"

/* Single value where type is fsgjt_media_preprinted_t */
/* (MediaPreprintedEnum) */
#define FSGJT_MEDIA_PREPRINTED               "media-preprinted"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_MEDIA_RECYCLED_PERCENTAGE \
  "media-recycled-percentage"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_MEDIA_SET_COUNT                "media-set-count"

/* Single value where type is fsgjt_media_size_name_t */
/* (MediaSizeName) */
#define FSGJT_MEDIA_SIZE_NAME                "media-size-name"

/* Single value where type is fsgjt_media_type_t (MediaTypeEnum) */
#define FSGJT_MEDIA_TYPE                     "media-type"

/* Single value where type is fsgjt_int32_t (Integer) */
#define FSGJT_MEDIA_WEIGHT                   "media-weight"

/************************************************************
 * fsgjtNewMedia - Creates a Media object using the provided 
 * name.
 *
 * param (output) fsgjt_object_t* media - Pointer to the new
 *      Media to create
 * param (input) name - Name of the media or NULL if Media
 *      name is not being specified.  The name can be any
 *      string.   
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewMedia(
               fsgjt_object_t* media, 
               fsgjt_text_t name);

#endif /* FSGJT_MEDIA_H */
