/********************************************************************
 * Job Ticket API (JTAPI) fsgjt_subscription.h
 *  
 * Copyright (c) 2004 High North Inc.
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_SUBSCRIPTION_H
#define FSGJT_SUBSCRIPTION_H

#include <fsgjt.h>
#include <fsgjt_enums.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_SUBSCRIPTION_OBJECT  "JSUB"

/************************************************************
 * Subscription attributes
 ***********************************************************/
/* Single value where type is fsgjt_charset_t (Charset) */
#define FSGJT_SUBSCRIPTION_CHARSET           "subscription-charset"

/* Single value where type is fsgjt_text_t (Text) */
#define FSGJT_SUBSCRIPTION_COMMENT           "subscription-comment"

/* Multiple values where type is fsgjt_subscription_event_t */
/* (SubscriptionEventEnum) */
#define FSGJT_SUBSCRIPTION_EVENTS            "subscription-events"

/* Multiple values where type is fsgjt_text_t (Text) */
#define FSGJT_SUBSCRIPTION_JOB_ATTRIBUTES \
  "subscription-job-attributes"

/* Single value where type is fsgjt_natural_language_t */
/* (NaturalLanguage) */
#define FSGJT_SUBSCRIPTION_NATURAL_LANGUAGE \
  "subscription-natural-language"

/* Single value where type is fsgjt_uri_t (URI) */
#define FSGJT_SUBSCRIPTION_SEND_TO_URI \
  "subscription-send-to-uri"

/************************************************************
 * fsgjtNewSubscription - Creates a Subscription object
 * having the provided notification URI.
 *
 * param (output) fsgjt_object_t* subscription - Pointer to
 *      the new Subscription object to create
 * param (input) fsgjt_uri_t sendToUri - URI for delivery of
 *      notifications for this Subscription
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewSubscription(
               fsgjt_object_t* subscription,
               fsgjt_uri_t sendToUri);

#endif /* FSGJT_SUBSCRIPTION_H */
